# Python Packaging helper
A Python Packaging helper CLI

### LEARN

[Learn about Python packaging](https://packaging.python.org/en/latest/)

[Simple packaging tutorial](https://packaging.python.org/en/latest/tutorials/packaging-projects/)


## Installation

using pip command line:
```
pip install helpmepack
```

OR

Download Build file:

[Source Distribution](https://files.pythonhosted.org/packages/b7/ce/5a49fd3a2c51701a469d75b7ee12ac16529513ad2dcd7c68933772c97d04/helpmepack-0.0.1.tar.gz)

[Built Distribution](https://files.pythonhosted.org/packages/b3/0e/b613098ff9e22176ff7c0681c4b7bccbe36cb2cd2540e43da32ec0f7325a/helpmepack-0.0.1-py3-none-any.whl)

## Usage

Please make sure you have your '.git' folder, and README.md, .gitignore, requirments.txt, LICENSE files - in your project directory.

All the other project files will be moved to the 'src' folder.

Make sure you running in the Project Main Directory.


## 
Run Python (in cmd/bash) in your project directory

```
from helpmepack import helpmepack 
```

```
helpmepack.main()
```
